@@ -1,13 +1,13 @@
 /** ===========================================================
  * @file
  *
- * This file is a part of digiKam project
- * <a href="http://www.digikam.org">http://www.digikam.org</a>
+ * This file is a part of KDE project
+ *
  *
  * @date   2004-02-01
  * @brief  plugin interface
  *
- * @author Copyright (C) 2004-2017 by Gilles Caulier
+ * @author Copyright (C) 2004-2018 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  * @author Copyright (C) 2012      by Victor Dodon
  *         <a href="mailto:dodonvictor at gmail dot com">dodonvictor at gmail dot com</a>
@@ -42,9 +42,9 @@
 #include <QAction>
 #include <QStandardPaths>
 
-// KDE includes
+// KF includes
 
-#include <kactioncollection.h>
+#include <KActionCollection>
 
 // Local includes
 
@@ -63,7 +63,7 @@ public:
     Private() :
         uiBaseName(QString())
     {
-        defaultWidget   = 0;
+        defaultWidget   = nullptr;
         defaultCategory = InvalidCategory;
     }
 
