@@ -9,7 +9,7 @@
  *
  * @author Copyright (C) 2009-2010 by Michael G. Hansen
  *         <a href="mailto:mike at mghansen dot de">mike at mghansen dot de</a>
- * @author Copyright (C) 2011-2017 by Gilles Caulier
+ * @author Copyright (C) 2011-2018 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  *
  * This program is free software; you can redistribute it
@@ -47,8 +47,8 @@ class KipiImageCollectionSelector : public ImageCollectionSelector
 
 public:
 
-    KipiImageCollectionSelector(KipiInterface* const interface, QWidget* const parent=0);
-    QList<ImageCollection> selectedImageCollections() const Q_DECL_OVERRIDE;
+    KipiImageCollectionSelector(KipiInterface* const interface, QWidget* const parent = nullptr);
+    QList<ImageCollection> selectedImageCollections() const override;
 
 public Q_SLOTS:
 
