@@ -9,7 +9,7 @@
  *
  * @author Copyright (C) 2009-2010 by Michael G. Hansen
  *         <a href="mailto:mike at mghansen dot de">mike at mghansen dot de</a>
- * @author Copyright (C) 2011-2017 by Gilles Caulier
+ * @author Copyright (C) 2011-2018 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  * @author Copyright (C) 2012 by Victor Dodon
  *         <a href="mailto:dodonvictor at gmail dot com">dodonvictor at gmail dot com</a>
@@ -80,7 +80,7 @@ int main(int argc, char* argv[])
 
     // Determine which with list we start
 
-    QList<QUrl>* startList = 0;
+    QList<QUrl>* startList = nullptr;
 
     if (parser.isSet(QString::fromLatin1("i")))
     {
@@ -120,7 +120,7 @@ int main(int argc, char* argv[])
         }
         else
         {
-            if (startList == 0)
+            if (startList == nullptr)
             {
                 qCritical() << "StartList is null. "
                             << "Please specify how the filenames you provided should be used.";
